@@ -6,7 +6,7 @@
  *  Updated   : 2010-04-29
  *  Notes     : nntp.h 1.5.11/1.6 with extensions for tin
  *
- * Copyright (c) 1991-2010 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2012 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,14 +45,6 @@
 #define NNTP_TCP_NAME	"nntp"
 #define NNTP_TCP_PORT	"119"
 
-/*
- * # seconds after which a read from the NNTP will timeout
- * NB: This is different from the NNTP server timing us out due to inactivity
- */
-#if defined(HAVE_ALARM) && defined(SIGALRM)
-#	define NNTP_READ_TIMEOUT	120
-#endif /* HAVE_ALARM && SIGALRM */
-
 /*
  * # times to try and reconnect to server after timeout
  */
@@ -161,7 +153,7 @@ enum f_type { OVER_T_ERROR, OVER_T_INT, OVER_T_STRING, OVER_T_FSTRING };
 
 /*
  * CAPABILITIES
- * remeber to update init.c and nntplib.c:check_extensions() if you change
+ * remember to update init.c and nntplib.c:check_extensions() if you change
  * t_capabilities
  */
 enum extension_type { NONE, CAPABILITIES, BROKEN };
