@@ -3,10 +3,10 @@
  *  Module    : inews.c
  *  Author    : I. Lea
  *  Created   : 1992-03-17
- *  Updated   : 2005-02-12
+ *  Updated   : 2009-04-07
  *  Notes     : NNTP built in version of inews
  *
- * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2012 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -58,19 +58,9 @@
 #endif /* NNTP_INEWS && !FORGERY */
 
 #if 0
-#	ifdef VMS
-#		ifdef MULTINET
-#			define netwrite	socket_write
-#			include "multinet_root:[multinet.include]netdb.h"
-#		else
-#			define netwrite	write
-#			include <netdb.h>
-#		endif /* MULTINET */
-#	else
-#		ifdef HAVE_NETDB_H
-#			include <netdb.h>
-#		endif /* HAVE_NETDB_H */
-#	endif /* VMS */
+#	ifdef HAVE_NETDB_H
+#		include <netdb.h>
+#	endif /* HAVE_NETDB_H */
 
 #	ifdef HAVE_SYS_SOCKET_H
 #		include <sys/socket.h>
@@ -126,25 +116,25 @@ submit_inews(
 		if (line[0] == '\0') /* end of headers */
 			break;
 
-		ptr = strchr(line, ':');
-		if (ptr - line == 4 && !strncasecmp(line, "From", 4)) {
-			STRCPY(from_name, line);
-		}
-
-		if (ptr - line == 10 && !strncasecmp(line, "Message-ID", 10)) {
-			STRCPY(message_id, ptr + 2);
-			id_in_article = TRUE;
-		}
+		if ((ptr = strchr(line, ':'))) {
+			if (ptr - line == 4 && !strncasecmp(line, "From", 4)) {
+				STRCPY(from_name, line);
+			}
 
+			if (ptr - line == 10 && !strncasecmp(line, "Message-ID", 10)) {
+				STRCPY(message_id, ptr + 2);
+				id_in_article = TRUE;
+			}
 #	ifdef USE_CANLOCK
-		if (ptr - line == 11 && !strncasecmp(line, "Cancel-Lock", 11))
-			can_lock_in_article = TRUE;
+			if (ptr - line == 11 && !strncasecmp(line, "Cancel-Lock", 11))
+				can_lock_in_article = TRUE;
 #	endif /* USE_CANLOCK */
+		}
 	}
 
 	if ((from_name[0] == '\0') || (from_name[6] == '\0')) {
 		/* we could silently add a From: line here if we want to... */
-		error_message(_(txt_error_no_from));
+		error_message(2, _(txt_error_no_from));
 		fclose(fp);
 		return ret_code;
 	}
@@ -160,8 +150,8 @@ submit_inews(
 	 *
 	 * check for valid From: line
 	 */
-	if (!tinrc.post_8bit_header && GNKSA_OK != gnksa_check_from(from_name + 6)) { /* error in address */
-		error_message(_(txt_invalid_from), from_name + 6);
+	if (!(group ? group->attribute->post_8bit_header : tinrc.post_8bit_header) && GNKSA_OK != gnksa_check_from(from_name + 6)) { /* error in address */
+		error_message(2, _(txt_invalid_from), from_name + 6);
 		fclose(fp);
 		return ret_code;
 	}
@@ -171,18 +161,18 @@ submit_inews(
 		rewind(fp);
 
 #	ifndef FORGERY
-		if ((ptr = build_sender()) && (!disable_sender)) {
+		if (!disable_sender && (ptr = build_sender())) {
 			sender = sender_needed(from_name + 6, group, ptr);
 			switch (sender) {
 				case -2: /* can't build Sender: */
-					error_message(_(txt_invalid_sender), ptr);
+					error_message(2, _(txt_invalid_sender), ptr);
 					fclose(fp);
 					return ret_code;
 					/* NOTREACHED */
 					break;
 
 				case -1: /* illegal From: (can't happen as check is done above already) */
-					error_message(_(txt_invalid_from), from_name + 6);
+					error_message(2, _(txt_invalid_from), from_name + 6);
 					fclose(fp);
 					return ret_code;
 					/* NOTREACHED */
@@ -193,7 +183,7 @@ submit_inews(
 #		ifdef CHARSET_CONVERSION
 					buffer_to_network(sender_hdr, group ? group->attribute->mm_network_charset : tinrc.mm_network_charset);
 #		endif /* CHARSET_CONVERSION */
-					if (!tinrc.post_8bit_header) {
+					if (!(group ? group->attribute->post_8bit_header : tinrc.post_8bit_header)) {
 						char *p;
 #		ifdef CHARSET_CONVERSION
 						p = rfc1522_encode(sender_hdr, group ? txt_mime_charsets[group->attribute->mm_network_charset] : txt_mime_charsets[tinrc.mm_network_charset], ismail);
@@ -217,7 +207,7 @@ submit_inews(
 		 * Receive CONT_POST or ERROR response code from NNTP server
 		 */
 		if (nntp_command("POST", CONT_POST, response, sizeof(response)) == NULL) {
-			error_message("%s", response);
+			error_message(2, "%s", response);
 			fclose(fp);
 			return ret_code;
 		}
@@ -267,11 +257,12 @@ submit_inews(
 #	ifdef USE_CANLOCK
 			if (!can_lock_in_article) {
 					char lock[1024];
-					const char *lptr = (const char *) 0;
+					char *lptr;
 
 					lock[0] = '\0';
 					if ((lptr = build_canlock(message_id, get_secret())) != NULL) {
 						STRCPY(lock, lptr);
+						free(lptr);
 						snprintf(buf, sizeof(buf), "Cancel-Lock: %s", lock);
 						u_put_server(buf);
 						u_put_server("\r\n");
@@ -297,9 +288,7 @@ submit_inews(
 
 			if (can_lock_in_article && !id_in_article) {
 				ptr = strchr(line, ':');
-				if (ptr - line == 11 && !strncasecmp(line, "Cancel-Lock", 11)) {
-					; /* skip line */
-				} else {
+				if (ptr - line != 11 || strncasecmp(line, "Cancel-Lock", 11)) {
 					u_put_server(line);
 					u_put_server("\r\n");
 				}
@@ -328,6 +317,8 @@ submit_inews(
 		 * Don't leave this loop if we only tried once to post and an
 		 * authentication request was received. Leave loop on any other
 		 * response or any further authentication requests.
+		 *
+		 * TODO: add 483 (RFC 3977) support
 		 */
 		if (((respcode == ERR_NOAUTH) || (respcode == NEED_AUTHINFO)) && (auth_error++ < 1) && (authenticate(nntp_server, userid, FALSE)))
 			leave_loop = FALSE;
@@ -344,7 +335,7 @@ submit_inews(
 	 */
 	if (respcode != OK_POSTED) {
 		/* TODO: -> lang.c */
-		error_message("Posting failed (%s)", str_trim(response));
+		error_message(2, "Posting failed (%s)", str_trim(response));
 		return ret_code;
 	}
 
@@ -399,10 +390,10 @@ submit_news_file(
 
 	a_message_id[0] = '\0';
 
-	fcc = checknadd_headers(name);
+	fcc = checknadd_headers(name, group);
 	FreeIfNeeded(fcc); /* we don't use it at the moment */
 
-	rfc15211522_encode(name, txt_mime_encodings[tinrc.post_mime_encoding], group, tinrc.post_8bit_header, ismail);
+	rfc15211522_encode(name, txt_mime_encodings[(group ? group->attribute->post_mime_encoding : tinrc.post_mime_encoding)], group, (group ? group->attribute->post_8bit_header : tinrc.post_8bit_header), ismail);
 
 #ifdef NNTP_INEWS
 	if (read_news_via_nntp && !read_saved_news && 0 == strcasecmp(tinrc.inews_prog, INTERNAL_CMD))
@@ -413,10 +404,10 @@ submit_news_file(
 #ifdef M_UNIX
 			/* use tinrc.inews_prog or 'inewsdir/inews -h' 'inews -h' */
 			if (0 != strcasecmp(tinrc.inews_prog, INTERNAL_CMD))
-				strncpy(buf, tinrc.inews_prog, sizeof(buf) - 1);
+				STRCPY(buf, tinrc.inews_prog);
 			else {
 				if (*inewsdir)
-					joinpath(buf, inewsdir, "inews -h");
+					joinpath(buf, sizeof(buf), inewsdir, "inews -h");
 				else
 					strcpy(buf, "inews -h");
 			}
@@ -467,7 +458,7 @@ sender_needed(
 	char sender_name[HEADER_LEN];
 
 #	ifdef DEBUG
-	if (debug == 2) {
+	if (debug & DEBUG_MISC) {
 		wait_message(3, "sender_needed From:=[%s]", from);
 		wait_message(3, "sender_needed Sender:=[%s]", sender);
 	}
@@ -490,8 +481,10 @@ sender_needed(
 	free(p);
 
 	from_at_pos = strchr(from_addr, '@');
-	sender_at_pos = strchr(sender_addr, '@');
-	sender_dot_pos = strchr(sender_at_pos, '.');
+	if ((sender_at_pos = strchr(sender_addr, '@')))
+		sender_dot_pos = strchr(sender_at_pos, '.');
+	else /* this case is catched by the gnksa_do_check_from() code above; anyway ... */
+		return -2;
 
 	if (strncasecmp(from_addr, sender_addr, (from_at_pos - from_addr)))
 		return 1; /* login differs */
