@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 2011-05-27
+ *  Updated   : 2011-09-12
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -740,7 +740,7 @@ u_put_server(
 #	ifdef DEBUG
 	if (debug & DEBUG_NNTP) {
 		if (strcmp(string, "\r\n"))
-			debug_print_file("NNTP", ">>> %s", string);
+			debug_print_file("NNTP", ">>>%s%s", logtime(), string);
 	}
 #	endif /* DEBUG */
 }
@@ -770,7 +770,7 @@ put_server(
 		s_puts("\r\n", nntp_wr_fp);
 #	ifdef DEBUG
 		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", ">>> %s", string);
+			debug_print_file("NNTP", ">>>%s%s", logtime(), string);
 #	endif /* DEBUG */
 		/*
 		 * remember the last command we wrote to be able to resend it after a
@@ -820,7 +820,7 @@ reconnect(
 
 	/*
 	 * set signal_context temporary to cReconnect to avoid trouble when receiving
-	 * SIGWINCH while beeing in prompt_yn()
+	 * SIGWINCH while being in prompt_yn()
 	 */
 	signal_context = cReconnect;
 
@@ -858,7 +858,7 @@ reconnect(
 			s_gets(last_put, NNTP_STRLEN, nntp_rd_fp);
 #	ifdef DEBUG
 			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<< %s", last_put);
+				debug_print_file("NNTP", "<<<%s%s", logtime(), last_put);
 #	endif /* DEBUG */
 			DEBUG_IO((stderr, _("Read (%s)\n"), last_put));
 		}
@@ -914,13 +914,13 @@ get_server(
 	 *   -the network connection went down
 	 */
 #	if defined(HAVE_ALARM) && defined(SIGALRM)
-	alarm(NNTP_READ_TIMEOUT);
+	alarm(tinrc.nntp_read_timeout_secs);
 #	endif /* HAVE_ALARM && SIGALRM */
 	while (nntp_rd_fp == NULL || s_gets(string, size, nntp_rd_fp) == NULL) {
 		if (errno == EINTR) {
 			errno = 0;
 #	if defined(HAVE_ALARM) && defined(SIGALRM)
-			alarm(NNTP_READ_TIMEOUT);		/* Restart the timer */
+			alarm(tinrc.nntp_read_timeout_secs);		/* Restart the timer */
 #	endif /* HAVE_ALARM && SIGALRM */
 			continue;
 		}
@@ -998,10 +998,7 @@ close_server(
 	s_end();
 	nntp_wr_fp = nntp_rd_fp = NULL;
 }
-#endif /* NNTP_ABLE */
 
-
-#ifdef NNTP_ABLE
 /*
  * Try and use CAPABILITIES here. Get this list before issuing other NNTP
  * commands because the correct methods may be mentioned in the list of
@@ -1067,7 +1064,7 @@ check_extensions(void)
 			while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #		ifdef DEBUG
 				if (debug & DEBUG_NNTP)
-					debug_print_file("NNTP", "<<< %s", ptr);
+					debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #		endif /* DEBUG */
 				/* look for version number(s) */
 				if (!nntp_caps.version && nntp_caps.type == CAPABILITIES) {
@@ -1262,10 +1259,10 @@ mode_reader(
 
 	if (!nntp_caps.reader) {
 		char line[NNTP_STRLEN];
-#ifdef DEBUG
+#	ifdef DEBUG
 		if (debug & DEBUG_NNTP)
 			debug_print_file("NNTP", "mode_reader() MODE READER");
-#endif /* DEBUG */
+#	endif /* DEBUG */
 		DEBUG_IO((stderr, "nntp_command(MODE READER)\n"));
 		put_server("MODE READER");
 
@@ -1303,10 +1300,10 @@ mode_reader(
 				return ret;
 
 			case ERR_COMMAND:
-#if 1
+#	if 1
 				ret = 0;
 				break;
-#endif /* 1 */
+#	endif /* 1 */
 
 			default:
 				break;
@@ -1359,7 +1356,7 @@ nntp_open(
 
 #	ifdef DEBUG
 	if (debug & DEBUG_NNTP)
-		debug_print_file("NNTP", "nntp_open() %s", nntp_server);
+		debug_print_file("NNTP", "nntp_open() %s:%d", nntp_server, nntp_tcp_port);
 #	endif /* DEBUG */
 
 	ret = server_init(nntp_server, NNTP_TCP_NAME, nntp_tcp_port, line, sizeof(line));
@@ -1733,14 +1730,14 @@ get_only_respcode(
 	if (tin_errno || ptr == NULL) {
 #	ifdef DEBUG
 		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "<<< Error: tin_error<>0 or ptr==NULL in get_only_respcode()");
+			debug_print_file("NNTP", "<<<%sError: tin_error<>0 or ptr==NULL in get_only_respcode()", logtime());
 #	endif /* DEBUG */
 		return -1;
 	}
 
 #	ifdef DEBUG
 	if (debug & DEBUG_NNTP)
-		debug_print_file("NNTP", "<<< %s", ptr);
+		debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 	respcode = (int) strtol(ptr, &end, 10);
 	DEBUG_IO((stderr, "get_only_respcode(%d)\n", respcode));
@@ -1764,14 +1761,14 @@ get_only_respcode(
 		if (tin_errno) {
 #	ifdef DEBUG
 			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<< Error: tin_errno <> 0");
+				debug_print_file("NNTP", "<<<%sError: tin_errno <> 0", logtime());
 #	endif /* DEBUG */
 			return -1;
 		}
 
 #	ifdef DEBUG
 		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "<<< %s", ptr);
+			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 		respcode = (int) strtol(ptr, &end, 10);
 		DEBUG_IO((stderr, "get_only_respcode(%d)\n", respcode));
@@ -1833,7 +1830,7 @@ get_respcode(
 			s_gets(last_put, NNTP_STRLEN, nntp_rd_fp);
 #	ifdef DEBUG
 			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<< %s", last_put);
+				debug_print_file("NNTP", "<<<%s%s", logtime(), last_put);
 #	endif /* DEBUG */
 			DEBUG_IO((stderr, _("Read (%s)\n"), last_put));
 		}
@@ -1845,14 +1842,14 @@ get_respcode(
 		if (tin_errno) {
 #	ifdef DEBUG
 			if (debug & DEBUG_NNTP)
-				debug_print_file("NNTP", "<<< Error: tin_errno <> 0");
+				debug_print_file("NNTP", "<<<%sError: tin_errno <> 0", logtime());
 #	endif /* DEBUG */
 				return -1;
 		}
 
 #	ifdef DEBUG
 		if (debug & DEBUG_NNTP)
-			debug_print_file("NNTP", "<<< %s", ptr);
+			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 		respcode = (int) strtol(ptr, &end, 10);
 		if (message != NULL && mlen > 1)				/* Pass out the rest of the text */
@@ -1961,7 +1958,7 @@ list_motd(
 			while ((ptr = tin_fgets(FAKE_NNTP_FP, FALSE)) != NULL) {
 #	ifdef DEBUG
 				if (debug & DEBUG_NNTP)
-					debug_print_file("NNTP", "<<< %s", ptr);
+					debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 				/*
 				 * according to draft-elie-nntp-list-additions-00.txt 2.4.2
